@@ -2,7 +2,7 @@ use strict;
 use warnings;
 use 5.014;
 
-package App::af 0.08 {
+package App::af 0.09 {
 
   use Moose::Role;
   use namespace::autoclean;
@@ -99,7 +99,6 @@ package App::af::role::alienfile {
   use Moose::Role;
   use namespace::autoclean;
   use MooseX::Types::Path::Tiny qw( AbsPath );
-  use Module::Load qw( load );
   use Path::Tiny qw( path );
   use File::Temp qw( tempdir );
   
@@ -134,7 +133,9 @@ package App::af::role::alienfile {
     if($self->class)
     {
       my $class = $self->class =~ /::/ ? $self->class : "Alien::" . $self->class;
-      load $class;
+      my $pm    = $class . '.pm';
+      $pm =~ s/::/\//g;
+      require $pm;
       if($class->can('runtime_prop') && $class->runtime_prop)
       {
         my $dist = path($class->dist_dir);
@@ -238,7 +239,7 @@ App::af - Command line tool for alienfile
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
